@@ -1,32 +1,36 @@
 __all__ = [
-    "resnest50",
-    "resnest101",
-    "resnest200",
-    "resnest269",
+    "resnest50_fpn",
+    "resnest101_fpn",
+    "resnest200_fpn",
+    "resnest269_fpn",
 ]
 
 from icevision.imports import *
 from icevision.utils import *
-from icevision.backbones.resnet_fpn import patch_param_groups
+from icevision.backbones.resnet_fpn_utils import patch_param_groups
 from torchvision.ops.feature_pyramid_network import LastLevelMaxPool
 from torchvision.models.detection.backbone_utils import (
     resnet_fpn_backbone,
     BackboneWithFPN,
 )
-import resnest.torch
+
+from icevision.soft_dependencies import SoftDependencies
+
+if SoftDependencies.resnest:
+    import resnest.torch
 
 
-# ResNeSt Backbones
 class Identity(nn.Module):
     def __init__(self):
-        super(Identity, self).__init__()
+        super().__init__()
 
     def forward(self, x):
         return x
 
 
+# TODO: resnest_name?
 def resnest_fpn_backbone(
-    resnest_name,
+    backbone_fn,
     pretrained,
     # norm_layer=misc_nn_ops.FrozenBatchNorm2d,
     trainable_layers=3,
@@ -34,7 +38,7 @@ def resnest_fpn_backbone(
     extra_blocks=None,
 ):
     """
-    Constructs a specified ResNet backbone with FPN on top. Freezes the specified number of layers in the backbone.
+    Constructs a specified ResNest backbone with FPN on top. Freezes the specified number of layers in the backbone.
 
     Examples::
 
@@ -61,8 +65,7 @@ def resnest_fpn_backbone(
         trainable_layers (int): number of trainable (not frozen) resnet layers starting from final block.
             Valid values are between 0 and 5, with 5 meaning all backbone layers are trainable.
     """
-    backbone = resnest_name(pretrained=pretrained)
-    # backbone = resnest50(pretrained=pretrained)
+    backbone = backbone_fn(pretrained=pretrained)
 
     backbone.fc = Identity()
     backbone.avgpool = Identity()
@@ -98,23 +101,23 @@ def resnest_fpn_backbone(
 
 
 def _resnest_fpn(name, pretrained: bool = True, **kwargs):
-    model = resnest_fpn_backbone(resnest_name=name, pretrained=pretrained, **kwargs)
+    model = resnest_fpn_backbone(backbone_fn=name, pretrained=pretrained, **kwargs)
     patch_param_groups(model)
 
     return model
 
 
-def resnest50(pretrained: bool = True, **kwargs):
+def resnest50_fpn(pretrained: bool = True, **kwargs):
     return _resnest_fpn(resnest.torch.resnest50, pretrained=pretrained, **kwargs)
 
 
-def resnest101(pretrained: bool = True, **kwargs):
+def resnest101_fpn(pretrained: bool = True, **kwargs):
     return _resnest_fpn(resnest.torch.resnest101, pretrained=pretrained, **kwargs)
 
 
-def resnest200(pretrained: bool = True, **kwargs):
+def resnest200_fpn(pretrained: bool = True, **kwargs):
     return _resnest_fpn(resnest.torch.resnest200, pretrained=pretrained, **kwargs)
 
 
-def resnest269(pretrained: bool = True, **kwargs):
+def resnest269_fpn(pretrained: bool = True, **kwargs):
     return _resnest_fpn(resnest.torch.resnest269, pretrained=pretrained, **kwargs)
