@@ -1,10 +1,13 @@
 from icevision.core.exceptions import *
+from icevision.core import tasks
+from icevision.core.components import *
 from icevision.core.id_map import *
 from icevision.core.class_map import *
 from icevision.core.mask import *
 from icevision.core.bbox import *
 from icevision.core.record_type import *
-from icevision.core.record_mixins import *
+from icevision.core.record_components import *
 from icevision.core.record import *
 from icevision.core.keypoints import *
 from icevision.core.record_utils import *
+from icevision.core.record_defaults import *
