@@ -21,37 +21,48 @@ class Dataset:
     def __init__(
         self,
         records: List[dict],
-        tfm: Transform = None,
+        tfm: Optional[Transform] = None,
     ):
         self.records = records
         self.tfm = tfm
+        # if self.tfm is not None:
+        #     self.tfm.setup(records[0].components_cls)
 
     def __len__(self):
         return len(self.records)
 
     def __getitem__(self, i):
-        data = self.records[i].load().as_dict()
+        record = self.records[i].load()
         if self.tfm is not None:
-            data = self.tfm(data)
-        return data
+            record = self.tfm(record)
+        return record
 
     def __repr__(self):
         return f"<{self.__class__.__name__} with {len(self.records)} items>"
 
     @classmethod
-    def from_images(cls, images: Sequence[np.array], tfm: Transform = None):
+    def from_images(
+        cls,
+        images: Sequence[np.array],
+        tfm: Transform = None,
+        class_map: Optional[ClassMap] = None,
+    ):
         """Creates a `Dataset` from a list of images.
 
         # Arguments
             images: `Sequence` of images in memory (numpy arrays).
             tfm: Transforms to be applied to each item.
         """
-        Record = create_mixed_record((ImageRecordMixin,))
         records = []
         for i, image in enumerate(images):
-            record = Record()
-            record.set_imageid(i)
+            record = BaseRecord((ImageRecordComponent(),))
+            record.set_record_id(i)
             record.set_img(image)
             records.append(record)
 
+            # TODO, HACK: adding class map because of `convert_raw_prediction`
+            record.add_component(ClassMapRecordComponent(task=tasks.detection))
+            if class_map is not None:
+                record.detection.set_class_map(class_map)
+
         return cls(records=records, tfm=tfm)
